@@ -1,6 +1,6 @@
 /* gpa.c - The GNU Privacy Assistant main file.
    Copyright (C) 2000-2002 G-N-U GmbH.
-   Copyright (C) 2005, 2008 g10 Code GmbH.
+   Copyright (C) 2005, 2008, 2012 g10 Code GmbH.
 
    This file is part of GPA
 
@@ -57,6 +57,8 @@ gboolean cms_hack;
 /* True if the ticker used for card operations should not be started.  */
 gboolean disable_ticker;
 
+/* True if the gpgme edit FSM shall output debug messages.  */
+gboolean debug_edit_fsm;
 
 /* Local variables.  */
 typedef struct
@@ -68,7 +70,10 @@ typedef struct
   gboolean start_settings;
   gboolean start_only_server;
   gboolean disable_x509;
+  gboolean enable_logging;
   gchar *options_filename;
+  char  *gpg_binary;
+  char  *gpgsm_binary;
 } gpa_args_t;
 
 static gpa_args_t args;
@@ -77,7 +82,7 @@ static gpa_args_t args;
 /* The copyright notice.  */
 static const char *copyright =
 "Copyright (C) 2000-2002 Miguel Coca, G-N-U GmbH, Intevation GmbH.\n"
-"Copyright (C) 2008, 2009 g10 Code GmbH.\n"
+"Copyright (C) 2005-2013 g10 Code GmbH.\n"
 "This program comes with ABSOLUTELY NO WARRANTY.\n"
 "This is free software, and you are welcome to redistribute it\n"
 "under certain conditions.  See the file COPYING for details.\n";
@@ -116,6 +121,14 @@ static GOptionEntry option_entries[] =
       &cms_hack, NULL, NULL },
     { "disable-ticker", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE,
       &disable_ticker, NULL, NULL },
+    { "debug-edit-fsm", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE,
+      &debug_edit_fsm, NULL, NULL },
+    { "enable-logging", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE,
+      &args.enable_logging, NULL, NULL },
+    { "gpg-binary", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_FILENAME,
+      &args.gpg_binary, NULL, NULL },
+    { "gpgsm-binary", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_FILENAME,
+      &args.gpgsm_binary, NULL, NULL },
     { NULL }
   };
 
@@ -288,14 +301,13 @@ print_version (void)
 
 
 
-#ifdef G_OS_WIN32
 static void
 dummy_log_func (const gchar *log_domain, GLogLevelFlags log_level,
                 const gchar *message, gpointer user_data)
 {
   /* Nothing to be done.  */
 }
-#endif /*G_OS_WIN32*/
+
 
 int
 main (int argc, char *argv[])
@@ -306,8 +318,10 @@ main (int argc, char *argv[])
   char *keyservers_configname = NULL;
   int i;
 
-#ifdef __MINGW32__
-  hide_gpa_console_window();
+  /* Under W32 logging is disabled by default to prevent MS Windows NT
+     from opening a console.  */
+#ifndef G_OS_WIN32
+  args.enable_logging = 1;
 #endif
 
   /* Set locale before option parsing for UTF-8 conversion.  */
@@ -330,28 +344,34 @@ main (int argc, char *argv[])
       exit (1);
     }
 
+  if (!args.enable_logging)
+    {
+#ifdef __MINGW32__
+      hide_gpa_console_window();
+#endif
+      g_log_set_handler ("Glib", G_LOG_LEVEL_CRITICAL
+                         | G_LOG_LEVEL_WARNING
+                         | G_LOG_LEVEL_MESSAGE
+                         | G_LOG_LEVEL_INFO, dummy_log_func, NULL);
 
-  /* Disable logging to prevent MS Windows NT from opening a
-     console.  */
+      g_log_set_handler ("Gdk", G_LOG_LEVEL_CRITICAL
+                         | G_LOG_LEVEL_WARNING
+                         | G_LOG_LEVEL_MESSAGE
+                         | G_LOG_LEVEL_INFO, dummy_log_func, NULL);
 
-#ifdef G_OS_WIN32
-  g_log_set_handler ("Glib", G_LOG_LEVEL_CRITICAL
-                             | G_LOG_LEVEL_WARNING
-                             | G_LOG_LEVEL_MESSAGE
-                             | G_LOG_LEVEL_INFO, dummy_log_func, NULL);
-
-  g_log_set_handler ("Gdk", G_LOG_LEVEL_CRITICAL
-                            | G_LOG_LEVEL_WARNING
-                            | G_LOG_LEVEL_MESSAGE
-                            | G_LOG_LEVEL_INFO, dummy_log_func, NULL);
-
-  g_log_set_handler ("Gtk", G_LOG_LEVEL_CRITICAL
-                            | G_LOG_LEVEL_WARNING
-                            | G_LOG_LEVEL_MESSAGE
-                            | G_LOG_LEVEL_INFO, dummy_log_func, NULL);
-#endif /*G_OS_WIN32*/
+      g_log_set_handler ("Gtk", G_LOG_LEVEL_CRITICAL
+                         | G_LOG_LEVEL_WARNING
+                         | G_LOG_LEVEL_MESSAGE
+                         | G_LOG_LEVEL_INFO, dummy_log_func, NULL);
+    }
 
   gtk_init (&argc, &argv);
+#ifdef G_OS_WIN32
+  gtk_settings_set_string_property(gtk_settings_get_default(),
+                                   "gtk-theme-name",
+                                   "MS-Windows",
+                                   "XProperty");
+#endif
 
   /* Default icon for all windows.  */
   gtk_window_set_default_icon_from_file (GPA_DATADIR "/gpa.png", &err);
@@ -392,8 +412,8 @@ main (int argc, char *argv[])
   }
 #endif
 
-  /* Prefer gpg2 over gpg1.  */
-  gpa_switch_to_gpg2 ();
+  /* Prefer gpg2 over gpg1 or use the requested gpg binary if given.  */
+  gpa_switch_to_gpg2 (args.gpg_binary, args.gpgsm_binary);
 
   /* Start the agent if needed.  We need to do this because the card
      manager uses direct assuan commands to the agent and thus expects
