@@ -1,8 +1,8 @@
 /* gpakeyselector.c - The GNU Privacy Assistant key selector.
    Copyright (C) 2003 Miguel Coca.
-   Copyright (C) 2005 g10 Code GmbH.
+   Copyright (C) 2005, 2008 g10 Code GmbH.
 
-   This file is part of GPA
+   This file is part of GPA.
 
    GPA is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,9 +18,7 @@
    along with GPA; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA  */
 
-#if HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include "gpa.h"
 #include "gpakeyselector.h"
@@ -136,11 +134,13 @@ gpa_key_selector_get_type (void)
 /* API */
 
 GtkWidget *
-gpa_key_selector_new (gboolean secret)
+gpa_key_selector_new (gboolean secret, gboolean only_usable_keys)
 {
   GtkWidget *sel = (GtkWidget*) g_object_new (GPA_KEY_SELECTOR_TYPE, NULL);
 
   GPA_KEY_SELECTOR (sel)->secret = secret;
+  GPA_KEY_SELECTOR (sel)->only_usable_keys = only_usable_keys;
+
   /* Disable the list while loading keys */
   gtk_widget_set_sensitive (GTK_WIDGET (sel), FALSE);
   if (secret)
@@ -216,6 +216,10 @@ gpa_key_selector_next_key (gpgme_key_t key, gpointer data)
   GtkTreeIter iter;
   const gchar *keyid;
   gchar *userid;
+
+  if (key && selector->only_usable_keys
+      && (key->revoked || key->disabled || key->expired || key->invalid))
+    return;
   
   selector->keys = g_list_prepend (selector->keys, key);
   store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (selector)));
@@ -230,16 +234,21 @@ gpa_key_selector_next_key (gpgme_key_t key, gpointer data)
 		      GPA_KEY_SELECTOR_COLUMN_USERID, userid,
 		      GPA_KEY_SELECTOR_COLUMN_KEY, key, -1);
   /* If this is a secret key selector, select the default key */
-  if (selector->secret) {
-    const gchar *key_fpr = key->subkeys->fpr;
-    const gchar *default_key = gpa_options_get_default_key 
-      (gpa_options_get_instance())->subkeys[0].fpr;
+  if (selector->secret)
+    {
+      const char *key_fpr = key->subkeys->fpr;
+      gpgme_key_t akey;
+      const char *default_key;
+      
+      akey = gpa_options_get_default_key (gpa_options_get_instance());
+      default_key = akey? akey->subkeys->fpr : NULL;
 
-    if (g_str_equal (key_fpr, default_key)) {
-      gtk_tree_selection_select_iter 
-	(gtk_tree_view_get_selection (GTK_TREE_VIEW (selector)),&iter);
+      if (default_key && g_str_equal (key_fpr, default_key)) 
+        {
+          gtk_tree_selection_select_iter 
+            (gtk_tree_view_get_selection (GTK_TREE_VIEW (selector)),&iter);
+        }
     }
-  }
   /* Clean up */
   g_free (userid);
 }
