@@ -19,7 +19,7 @@
 
 
 /* Violation of GNOME standards: Cancel does not revert a previous
-   apply.  Excvept for the UI mode, we do not auto-apply or syntax
+   apply.  Except for the UI mode, we do not auto-apply or syntax
    check after focus change.  The rationale for this is that:
 
      * gpgconf operations are expensive.
@@ -306,7 +306,7 @@ default_key_frame (SettingsDlg *dialog)
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   gtk_frame_set_label_widget (GTK_FRAME (frame), label);
 
-  list = gpa_key_selector_new (TRUE);
+  list = gpa_key_selector_new (TRUE, FALSE);
   dialog->default_key.list = GPA_KEY_SELECTOR (list);
   gtk_tree_selection_set_mode (gtk_tree_view_get_selection 
 			       (GTK_TREE_VIEW (list)), GTK_SELECTION_SINGLE);
